package cli

import (
    "fmt"
    "os"
    "gitea.armuli.eu/museum-digital/museum-digital-webdav-uploader/src/uploadsrcdir"
    "gitea.armuli.eu/museum-digital/museum-digital-webdav-uploader/src/webdavupload"
)

// Integration: Uploads, if there is uploadable data and no import currently
// scheduled.
func Upload() {

    config := loadConfigFromFile()
    uploadableMetadata, uploadableMedia := uploadsrcdir.GetUploadableFiles(config)

    // If there are no files to upload, do nothing
    if len(uploadableMetadata) == 0 && len(uploadableMedia) == 0 {
        fmt.Println("No uploadable files identified.")
        return
    }

    // Ensure no files are too new too recent - if any are, say so and abort.
    if uploadsrcdir.CheckAnyFileIsTooRecent(uploadableMedia) || uploadsrcdir.CheckAnyFileIsTooRecent(uploadableMetadata) {
        fmt.Println("Some of the files have been updated too recently (1min). Blocking upload to prevent accidental uploads in the middle of an ongoing digitization effort.")
        return
    }

    // Open WebDAV client
    c := webdavupload.GetWebdavClient(config)

    // Check that the remote is not currently occupied.
    if webdavupload.CheckRemoteIsFree(c) == false {
        fmt.Println("The remote is currently occupied (very recent files, or an import config is currently waiting to be processed, are present).")
        return
    }

    // Upload the files
    if len(uploadableMetadata) > 0 {
        webdavupload.UploadMetadataFiles(c, os.Stdout, uploadableMetadata)
        webdavupload.BatchUnlink(os.Stdout, uploadableMetadata)
    }
    if len(uploadableMedia) > 0 {
        webdavupload.UploadMediaFiles(c, os.Stdout, uploadableMedia)
        webdavupload.BatchUnlink(os.Stdout, uploadableMedia)
    }

    // Generate the import config.
    fmt.Println("Generating and uploading import configuration")
    webdavupload.SetImportConfigToTheRemote(c, config)
    fmt.Println("DONE")

}
